shithub: pokered

Download patch

ref: 7ee8a6509e323ec012ece6273809e46830c29239
parent: 236426138bf085c4b7b854b43d910370fffca290
author: Rangi <remy.oukaour+rangi42@gmail.com>
date: Sat Aug 28 13:02:20 EDT 2021

wcf4b -> wStringBuffer

--- a/data/text/text_1.asm
+++ b/data/text/text_1.asm
@@ -60,7 +60,7 @@
 _FoundItemText::
 	text "<PLAYER> found"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/data/text/text_2.asm
+++ b/data/text/text_2.asm
@@ -18,7 +18,7 @@
 	prompt
 
 _TradeWentToText::
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text " went"
 	line "to @"
 	text_ram wLinkEnemyTrainerName
@@ -28,7 +28,7 @@
 _TradeForText::
 	text "For <PLAYER>'s"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text ","
 	done
 
@@ -70,7 +70,7 @@
 _TradeforText::
 	text "for <PLAYER>'s"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "."
 	done
 
@@ -106,7 +106,7 @@
 _LinedUpText::
 	text " lined up!"
 	line "Scored @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text " coins!"
 	done
 
@@ -1094,8 +1094,8 @@
 	cont "@"
 	text_end
 
-_CF4BText::
-	text_ram wcf4b
+_MoveNameText::
+	text_ram wStringBuffer
 	text "@"
 
 _ExclamationPoint1Text::
@@ -1559,7 +1559,7 @@
 	done
 
 _MonWasStoredText::
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text " was"
 	line "stored in Box @"
 	text_ram wBoxNumString
@@ -1577,11 +1577,11 @@
 	prompt
 
 _MonIsTakenOutText::
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text " is"
 	line "taken out."
 	cont "Got @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "."
 	prompt
 
@@ -1606,19 +1606,17 @@
 _OnceReleasedText::
 	text "Once released,"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text " is"
 	cont "gone forever. OK?"
 	done
 
 _MonWasReleasedText::
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text " was"
 	line "released outside."
 	cont "Bye @"
-
-_CF4BExclamationText::
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!"
 	prompt
 
--- a/data/text/text_3.asm
+++ b/data/text/text_3.asm
@@ -33,7 +33,7 @@
 	text_end
 
 _EvolvedText::
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text " evolved"
 	done
 
@@ -46,7 +46,7 @@
 
 _StoppedEvolvingText::
 	text "Huh? @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text_start
 	line "stopped evolving!"
 	prompt
@@ -53,7 +53,7 @@
 
 _IsEvolvingText::
 	text "What? @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text_start
 	line "is evolving!"
 	done
@@ -96,7 +96,7 @@
 _MonsStatsRoseText::
 	text "<USER>'s"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "@"
 	text_end
 
@@ -111,7 +111,7 @@
 _MonsStatsFellText::
 	text "<TARGET>'s"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "@"
 	text_end
 
--- a/data/text/text_4.asm
+++ b/data/text/text_4.asm
@@ -27,7 +27,7 @@
 	done
 
 _PokemartTellBuyPriceText::
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "?"
 	line "That will be"
 	cont "¥@"
@@ -85,7 +85,7 @@
 	text_ram wLearnMoveMonName
 	text " learned"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
@@ -97,7 +97,7 @@
 _AbandonLearningText::
 	text "Abandon learning"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "?"
 	done
 
@@ -106,7 +106,7 @@
 	text_start
 	line "did not learn"
 	cont "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!"
 	prompt
 
@@ -115,7 +115,7 @@
 	text " is"
 	line "trying to learn"
 	cont "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!"
 
 	para "But, @"
@@ -127,7 +127,7 @@
 	para "Delete an older"
 	line "move to make room"
 	cont "for @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "?"
 	done
 
--- a/data/text/text_5.asm
+++ b/data/text/text_5.asm
@@ -87,7 +87,7 @@
 	text " was"
 	cont "sent to #MON"
 	cont "BOX @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text " on PC!"
 	done
 
--- a/data/text/text_6.asm
+++ b/data/text/text_6.asm
@@ -72,7 +72,7 @@
 	text_ram wcd6d
 	text "'s"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text " rose."
 	prompt
 
@@ -138,13 +138,13 @@
 	done
 
 _PPMaxedOutText::
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "'s PP"
 	line "is maxed out."
 	prompt
 
 _PPIncreasedText::
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "'s PP"
 	line "increased."
 	prompt
@@ -164,11 +164,11 @@
 _TeachMachineMoveText::
 	text "It contained"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!"
 
 	para "Teach @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text_start
 	line "to a #MON?"
 	done
@@ -178,12 +178,12 @@
 	text " is not"
 	line "compatible with"
 	cont "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "."
 
 	para "It can't learn"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "."
 	prompt
 
--- a/data/text/text_7.asm
+++ b/data/text/text_7.asm
@@ -3,7 +3,7 @@
 	text_end
 
 _ItemUseText002::
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!"
 	done
 
@@ -12,7 +12,7 @@
 	text_end
 
 _GotOnBicycleText2::
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!"
 	prompt
 
@@ -22,7 +22,7 @@
 
 _GotOffBicycleText2::
 	text "the @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "."
 	prompt
 
@@ -36,7 +36,7 @@
 _IsItOKToTossItemText::
 	text "Is it OK to toss"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "?"
 	prompt
 
@@ -49,7 +49,7 @@
 	text_ram wcd6d
 	text " knows"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!"
 	prompt
 
--- a/engine/battle/core.asm
+++ b/engine/battle/core.asm
@@ -2239,7 +2239,7 @@
 	ld a, [wcf91]
 	ld [wd11e], a
 	call GetItemName
-	call CopyStringToCF4B ; copy name
+	call CopyToStringBuffer
 	xor a
 	ld [wPseudoItemID], a
 	call UseItem
@@ -3544,7 +3544,7 @@
 	ld a, RAGE
 	ld [wd11e], a
 	call GetMoveName
-	call CopyStringToCF4B
+	call CopyToStringBuffer
 	xor a
 	ld [wPlayerMoveEffect], a
 	ld hl, PlayerCanExecuteMove
@@ -3746,7 +3746,7 @@
 	ret
 
 _PrintMoveName:
-	text_far _CF4BText
+	text_far _MoveNameText
 	text_asm
 	ld hl, ExclamationPointPointerTable
 	ld a, [wd11e] ; exclamation point num
@@ -5108,7 +5108,7 @@
 	call IncrementMovePP
 ; the follow two function calls are used to reload the move name
 	call GetMoveName
-	call CopyStringToCF4B
+	call CopyToStringBuffer
 	ld a, $01
 	and a
 	ret
@@ -5609,7 +5609,7 @@
 	ld [wNameListType], a
 	call GetName
 	ld de, wcd6d
-	call CopyStringToCF4B
+	call CopyToStringBuffer
 EnemyCanExecuteMove:
 	xor a
 	ld [wMonIsDisobedient], a
@@ -6046,7 +6046,7 @@
 	ld a, RAGE
 	ld [wd11e], a
 	call GetMoveName
-	call CopyStringToCF4B
+	call CopyToStringBuffer
 	xor a
 	ld [wEnemyMoveEffect], a
 	ld hl, EnemyCanExecuteMove
@@ -6088,7 +6088,7 @@
 	ld [wNameListType], a
 	call GetName
 	ld de, wcd6d
-	jp CopyStringToCF4B
+	jp CopyToStringBuffer
 
 LoadEnemyMonData:
 	ld a, [wLinkState]
--- a/engine/battle/effects.asm
+++ b/engine/battle/effects.asm
@@ -751,7 +751,7 @@
 	jr z, .findStatName_outer
 	jr .findStatName_inner
 .foundStatName
-	ld de, wcf4b
+	ld de, wStringBuffer
 	ld bc, $a
 	jp CopyData
 
--- a/engine/events/cinnabar_lab.asm
+++ b/engine/events/cinnabar_lab.asm
@@ -116,7 +116,7 @@
 	ld a, [wFossilMon]
 	ld [wd11e], a
 	call GetMonName
-	call CopyStringToCF4B
+	call CopyToStringBuffer
 	ld a, [wFossilItem]
 	ld [wd11e], a
 	call GetItemName
--- a/engine/events/give_pokemon.asm
+++ b/engine/events/give_pokemon.asm
@@ -18,7 +18,7 @@
 	callfar LoadEnemyMonData
 	call SetPokedexOwnedFlag
 	callfar SendNewMonToBox
-	ld hl, wcf4b
+	ld hl, wStringBuffer
 	ld a, [wCurrentBoxNum]
 	and $7f
 	cp 9
--- a/engine/events/pokemart.asm
+++ b/engine/events/pokemart.asm
@@ -159,7 +159,7 @@
 	ld a, [wcf91] ; item ID
 	ld [wd11e], a ; store item ID for GetItemName
 	call GetItemName
-	call CopyStringToCF4B ; copy name to wcf4b
+	call CopyToStringBuffer
 	ld hl, PokemartTellBuyPriceText
 	call PrintText
 	hlcoord 14, 7
--- a/engine/items/item_effects.asm
+++ b/engine/items/item_effects.asm
@@ -1307,9 +1307,9 @@
 	jr nz, .statNameInnerLoop
 	jr .statNameLoop
 .gotStatName
-	ld de, wcf4b
+	ld de, wStringBuffer
 	ld bc, 10
-	call CopyData ; copy the stat's name to wcf4b
+	call CopyData ; copy the stat's name to wStringBuffer
 	ld a, SFX_HEAL_AILMENT
 	call PlaySound
 	ld hl, VitaminStatRoseText
@@ -1984,7 +1984,7 @@
 	ld a, [hl]
 	ld [wd11e], a
 	call GetMoveName
-	call CopyStringToCF4B ; copy name to wcf4b
+	call CopyToStringBuffer
 	pop hl
 	ld a, [wPPRestoreItem]
 	cp ETHER
@@ -2161,7 +2161,7 @@
 	ld a, [wd11e]
 	ld [wMoveNum], a
 	call GetMoveName
-	call CopyStringToCF4B ; copy name to wcf4b
+	call CopyToStringBuffer
 	pop af
 	ld hl, BootedUpTMText
 	jr nc, .printBootedUpMachineText
@@ -2187,7 +2187,7 @@
 	ld a, [wcf91]
 	push af
 .chooseMon
-	ld hl, wcf4b
+	ld hl, wStringBuffer
 	ld de, wTempMoveNameBuffer
 	ld bc, 14
 	call CopyData ; save the move name because DisplayPartyMenu will overwrite it
@@ -2198,7 +2198,7 @@
 	call DisplayPartyMenu
 	push af
 	ld hl, wTempMoveNameBuffer
-	ld de, wcf4b
+	ld de, wStringBuffer
 	ld bc, 14
 	call CopyData
 	pop af
@@ -2553,7 +2553,7 @@
 	ld a, [wcf91]
 	ld [wd11e], a
 	call GetItemName
-	call CopyStringToCF4B ; copy name to wcf4b
+	call CopyToStringBuffer
 	ld hl, IsItOKToTossItemText
 	call PrintText
 	hlcoord 14, 7
@@ -2573,7 +2573,7 @@
 	ld a, [wcf91]
 	ld [wd11e], a
 	call GetItemName
-	call CopyStringToCF4B ; copy name to wcf4b
+	call CopyToStringBuffer
 	ld hl, ThrewAwayItemText
 	call PrintText
 	pop hl
--- a/engine/menus/start_sub_menus.asm
+++ b/engine/menus/start_sub_menus.asm
@@ -367,7 +367,7 @@
 	ld a, [wcf91]
 	ld [wd11e], a
 	call GetItemName
-	call CopyStringToCF4B ; copy name to wcf4b
+	call CopyToStringBuffer
 	ld a, [wcf91]
 	cp BICYCLE
 	jr nz, .notBicycle2
--- a/engine/movie/oak_speech/oak_speech2.asm
+++ b/engine/movie/oak_speech/oak_speech2.asm
@@ -15,7 +15,7 @@
 	xor a ; NAME_PLAYER_SCREEN
 	ld [wNamingScreenType], a
 	call DisplayNamingScreen
-	ld a, [wcf4b]
+	ld a, [wStringBuffer]
 	cp "@"
 	jr z, .customName
 	call ClearScreen
@@ -48,7 +48,7 @@
 	ld a, NAME_RIVAL_SCREEN
 	ld [wNamingScreenType], a
 	call DisplayNamingScreen
-	ld a, [wcf4b]
+	ld a, [wStringBuffer]
 	cp "@"
 	jr z, .customName
 	call ClearScreen
--- a/engine/movie/trade.asm
+++ b/engine/movie/trade.asm
@@ -189,7 +189,7 @@
 	ld [wd11e], a
 	call GetMonName
 	ld hl, wcd6d
-	ld de, wcf4b
+	ld de, wStringBuffer
 	ld bc, NAME_LENGTH
 	call CopyData
 	ld a, [wTradedEnemyMonSpecies]
--- a/engine/movie/trade2.asm
+++ b/engine/movie/trade2.asm
@@ -10,7 +10,7 @@
 	lb bc, LEADING_ZEROES | 1, 3
 	call PrintNumber
 	hlcoord 5, 2
-	ld de, wcf4b
+	ld de, wStringBuffer
 	call PlaceString
 	hlcoord 8, 4
 	ld de, wTradedPlayerMonOT
--- a/engine/pokemon/evos_moves.asm
+++ b/engine/pokemon/evos_moves.asm
@@ -114,7 +114,7 @@
 	ld a, [wWhichPokemon]
 	ld hl, wPartyMonNicks
 	call GetPartyMonName
-	call CopyStringToCF4B
+	call CopyToStringBuffer
 	ld hl, IsEvolvingText
 	call PrintText
 	ld c, 50
@@ -268,7 +268,7 @@
 	pop af
 	ld [wd0b5], a
 	ld hl, wcd6d
-	ld de, wcf4b
+	ld de, wStringBuffer
 .compareNamesLoop
 	ld a, [de]
 	inc de
@@ -368,7 +368,7 @@
 	ld [wMoveNum], a
 	ld [wd11e], a
 	call GetMoveName
-	call CopyStringToCF4B
+	call CopyToStringBuffer
 	predef LearnMove
 .done
 	ld a, [wcf91]
--- a/engine/slots/slot_machine.asm
+++ b/engine/slots/slot_machine.asm
@@ -445,7 +445,7 @@
 	ld a, [hli]
 	ld h, [hl]
 	ld l, a
-	ld de, wcf4b
+	ld de, wStringBuffer
 	ld bc, 4
 	call CopyData
 	pop hl
--- a/home/copy_string.asm
+++ b/home/copy_string.asm
@@ -1,9 +1,9 @@
-; copies a string from [de] to [wcf4b]
-CopyStringToCF4B::
-	ld hl, wcf4b
+; copies a string from de to wStringBuffer
+CopyToStringBuffer::
+	ld hl, wStringBuffer
 	; fall through
 
-; copies a string from [de] to [hl]
+; copies a string from de to hl
 CopyString::
 	ld a, [de]
 	inc de
--- a/home/list_menu.asm
+++ b/home/list_menu.asm
@@ -157,7 +157,7 @@
 	call GetPartyMonName
 .storeChosenEntry ; store the menu entry that the player chose and return
 	ld de, wcd6d
-	call CopyStringToCF4B ; copy name to wcf4b
+	call CopyToStringBuffer
 	ld a, CHOSE_MENU_ITEM
 	ld [wMenuExitMethod], a
 	ld a, [wCurrentMenuItem]
--- a/text/BillsHouse.asm
+++ b/text/BillsHouse.asm
@@ -56,7 +56,7 @@
 _SSTicketReceivedText::
 	text "<PLAYER> received"
 	line "an @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/BluesHouse.asm
+++ b/text/BluesHouse.asm
@@ -14,7 +14,7 @@
 _GotMapText::
 	text "<PLAYER> got a"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/CeladonCity.asm
+++ b/text/CeladonCity.asm
@@ -42,7 +42,7 @@
 _ReceivedTM41Text::
 	text "<PLAYER> received"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/CeladonDiner.asm
+++ b/text/CeladonDiner.asm
@@ -44,7 +44,7 @@
 _ReceivedCoinCaseText::
 	text "<PLAYER> received"
 	line "a @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/CeladonGym.asm
+++ b/text/CeladonGym.asm
@@ -64,7 +64,7 @@
 _ReceivedTM21Text::
 	text "<PLAYER> received"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/CeladonMart3F.asm
+++ b/text/CeladonMart3F.asm
@@ -10,7 +10,7 @@
 _ReceivedTM18Text::
 	text "<PLAYER> received"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/CeladonMartRoof.asm
+++ b/text/CeladonMartRoof.asm
@@ -17,7 +17,7 @@
 _CeladonMartRoofText_484f9::
 	text "<PLAYER> received"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
@@ -25,7 +25,7 @@
 	text_start
 
 	para "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text " contains"
 	line "ICE BEAM!"
 
@@ -47,7 +47,7 @@
 _CeladonMartRoofText_4850a::
 	text "<PLAYER> received"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
@@ -55,7 +55,7 @@
 	text_start
 
 	para "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text " contains"
 	line "ROCK SLIDE!"
 
@@ -137,7 +137,7 @@
 	done
 
 _VendingMachineText5::
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text_start
 	line "popped out!"
 	done
--- a/text/CinnabarGym.asm
+++ b/text/CinnabarGym.asm
@@ -45,7 +45,7 @@
 _ReceivedTM38Text::
 	text "<PLAYER> received"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/CinnabarLabFossilRoom.asm
+++ b/text/CinnabarLabFossilRoom.asm
@@ -30,7 +30,7 @@
 	line "back to life!"
 
 	para "It was @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text_start
 	line "like I think!"
 	prompt
@@ -43,7 +43,7 @@
 
 	para "It is fossil of"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text ", a"
 	cont "#MON that is"
 	cont "already extinct!"
--- a/text/CinnabarLabMetronomeRoom.asm
+++ b/text/CinnabarLabMetronomeRoom.asm
@@ -9,7 +9,7 @@
 _ReceivedTM35Text::
 	text "<PLAYER> received "
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/CopycatsHouse2F.asm
+++ b/text/CopycatsHouse2F.asm
@@ -29,7 +29,7 @@
 _ReceivedTM31Text::
 	text "<PLAYER> received"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/FuchsiaGoodRodHouse.asm
+++ b/text/FuchsiaGoodRodHouse.asm
@@ -19,7 +19,7 @@
 
 	para "<PLAYER> received"
 	line "a @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/FuchsiaGym_2.asm
+++ b/text/FuchsiaGym_2.asm
@@ -27,7 +27,7 @@
 _ReceivedTM06Text::
 	text "<PLAYER> received"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/MrFujisHouse.asm
+++ b/text/MrFujisHouse.asm
@@ -50,7 +50,7 @@
 _ReceivedFluteText::
 	text "<PLAYER> received"
 	line "a @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/MrPsychicsHouse.asm
+++ b/text/MrPsychicsHouse.asm
@@ -8,7 +8,7 @@
 _ReceivedTM29Text::
 	text "<PLAYER> received"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/MtMoonB2F.asm
+++ b/text/MtMoonB2F.asm
@@ -11,7 +11,7 @@
 _MtMoon3Text_49f6f::
 	text "<PLAYER> got the"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/PokemonFanClub.asm
+++ b/text/PokemonFanClub.asm
@@ -85,7 +85,7 @@
 ReceivedBikeVoucherText::
 	text "<PLAYER> received"
 	line "a @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/Route1.asm
+++ b/text/Route1.asm
@@ -15,7 +15,7 @@
 _Route1Text_1cae8::
 	text "<PLAYER> got"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/Route12SuperRodHouse.asm
+++ b/text/Route12SuperRodHouse.asm
@@ -18,7 +18,7 @@
 
 	para "<PLAYER> received"
 	line "a @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/Route24.asm
+++ b/text/Route24.asm
@@ -14,7 +14,7 @@
 _Route24Text_5151a::
 	text "<PLAYER> received"
 	line "a @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/SSAnneCaptainsRoom.asm
+++ b/text/SSAnneCaptainsRoom.asm
@@ -34,7 +34,7 @@
 _ReceivedHM01Text::
 	text "<PLAYER> got"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/SafariZoneSecretHouse.asm
+++ b/text/SafariZoneSecretHouse.asm
@@ -17,7 +17,7 @@
 _ReceivedHM03Text::
 	text "<PLAYER> received"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/SilphCo11F.asm
+++ b/text/SilphCo11F.asm
@@ -22,7 +22,7 @@
 _ReceivedSilphCoMasterBallText::
 	text "<PLAYER> got a"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/SilphCo2F.asm
+++ b/text/SilphCo2F.asm
@@ -12,7 +12,7 @@
 _ReceivedTM36Text::
 	text "<PLAYER> got"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/VermilionGym_2.asm
+++ b/text/VermilionGym_2.asm
@@ -26,7 +26,7 @@
 _ReceivedTM24Text::
 	text "<PLAYER> received "
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/VermilionOldRodHouse.asm
+++ b/text/VermilionOldRodHouse.asm
@@ -18,7 +18,7 @@
 
 	para "<PLAYER> received"
 	line "an @"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/text/WardensHouse.asm
+++ b/text/WardensHouse.asm
@@ -46,7 +46,7 @@
 _ReceivedHM04Text::
 	text "<PLAYER> received"
 	line "@"
-	text_ram wcf4b
+	text_ram wStringBuffer
 	text "!@"
 	text_end
 
--- a/wram.asm
+++ b/wram.asm
@@ -1055,7 +1055,7 @@
 NEXTU
 	ds 29
 ; storage buffer for various strings
-wcf4b:: ds 20
+wStringBuffer:: ds 20
 
 NEXTU
 	ds 29
--- a/engine/menus/naming_screen.asm
+++ b/engine/menus/naming_screen.asm
@@ -39,7 +39,7 @@
 	pop hl
 	pop af
 	ld [wUpdateSpritesEnabled], a
-	ld a, [wcf4b]
+	ld a, [wStringBuffer]
 	cp "@"
 	ret nz
 .declinedNickname
@@ -63,7 +63,7 @@
 	call GBPalWhiteOutWithDelay3
 	call RestoreScreenTilesAndReloadTilePatterns
 	call LoadGBPal
-	ld a, [wcf4b]
+	ld a, [wStringBuffer]
 	cp "@"
 	jr z, .playerCancelled
 	ld hl, wPartyMonNicks
@@ -109,7 +109,7 @@
 	ld a, 7
 	ld [wMaxMenuItem], a
 	ld a, "@"
-	ld [wcf4b], a
+	ld [wStringBuffer], a
 	xor a
 	ld hl, wNamingScreenSubmitName
 	ld [hli], a
@@ -157,7 +157,7 @@
 
 .submitNickname
 	pop de
-	ld hl, wcf4b
+	ld hl, wStringBuffer
 	ld bc, NAME_LENGTH
 	call CopyData
 	call GBPalWhiteOutWithDelay3
@@ -375,7 +375,7 @@
 	lb bc, 1, 10
 	call ClearScreenArea
 	hlcoord 10, 2
-	ld de, wcf4b
+	ld de, wStringBuffer
 	call PlaceString
 	hlcoord 10, 3
 	ld a, [wNamingScreenType]
@@ -437,9 +437,9 @@
 
 INCLUDE "data/text/dakutens.asm"
 
 ; calculates the length of the string at wcf4b and stores it in c
 CalcStringLength:
-	ld hl, wcf4b
+	ld hl, wStringBuffer
 	ld c, $0
 .loop
 	ld a, [hl]
@@ -437,9 +437,9 @@
 INCLUDE "data/text/dakutens.asm"
 
-; calculates the length of the string at wcf4b and stores it in c
+; calculates the length of the string at wStringBuffer and stores it in c
 CalcStringLength:
--- a/home/give.asm
+++ b/home/give.asm
@@ -1,6 +1,6 @@
 GiveItem::
 ; Give player quantity c of item b,
 ; and copy the item's name to wcf4b.
 ; Return carry on success.
 	ld a, b
 	ld [wd11e], a
@@ -11,7 +11,7 @@
 	call AddItemToInventory
 	ret nc
 	call GetItemName
-	call CopyStringToCF4B
+	call CopyToStringBuffer
 	scf
 	ret
 
@@ -1,6 +1,6 @@
 GiveItem::
 ; Give player quantity c of item b,
-; and copy the item's name to wcf4b.
+; and copy the item's name to wStringBuffer.
 ; Return carry on success.
 	ld a, b